// $Id: DebugCondition.cc 11371 2010-03-28 17:00:33Z m9710797 $

#include "DebugCondition.hh"
#include "TclObject.hh"

namespace openmsx {

unsigned DebugCondition::lastId = 0;

DebugCondition::DebugCondition(GlobalCliComm& cliComm,
                               std::auto_ptr<TclObject> command,
                               std::auto_ptr<TclObject> condition)
	: BreakPointBase(cliComm, command, condition)
	, id(++lastId)
{
}

unsigned DebugCondition::getId() const
{
	return id;
}

} // namespace openmsx

